| dual_vector | R Documentation |
Wraps a list of dual objects in a container that supports [] indexing
and length(), so that user functions can use natural
theta[1] notation.
dual_vector(...)
... |
Dual objects, or a single list of dual objects. |
A dual_vector.
dv <- dual_vector(dual(1, 0), dual(2, 1))
length(dv)
value(dv[1])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.