| differentiate_n | R Documentation |
Evaluates f at a dual variable seeded for order n,
returning the function value and all derivatives from 1 to n.
differentiate_n(f, x, order)
f |
A function of one numeric argument. |
x |
A numeric value at which to differentiate. |
order |
A positive integer: the maximum derivative order. |
A named list with components value, d1,
d2, ..., d<order>.
differentiate_n(sin, pi/4, order = 4)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.