| dual-math2 | R Documentation |
Implements round and signif for dual numbers. These are
piecewise constant functions, so the derivative is zero almost everywhere.
## S4 method for signature 'dualr'
Math2(x, digits)
x |
A |
digits |
Integer; number of digits for rounding. |
A dual with the rounded value and zero derivative.
x <- dual_variable(3.14159)
value(round(x, 2))
deriv(round(x, 2))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.