| dual_constant | R Documentation |
Wraps a numeric value as a dual with zero derivative, representing a constant with respect to the differentiation variable.
dual_constant(x)
x |
A numeric value. |
A dual with value = x and deriv = 0.
k <- dual_constant(5)
deriv(k)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.