| dual_constant_n | R Documentation |
Wraps a numeric value as a nested dual with all derivative components
zero, representing a constant with respect to the differentiation
variable at nesting depth n.
dual_constant_n(x, order)
x |
A numeric value. |
order |
A non-negative integer specifying the nesting depth. |
A (possibly nested) dual number with zero derivatives.
k <- dual_constant_n(5, order = 3)
deriv_n(k, 1)
deriv_n(k, 2)
deriv_n(k, 3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.